"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Pixel = void 0;
const image_optimizer_1 = require("next/dist/server/image-optimizer");
const config_shared_1 = require("next/dist/server/config-shared");
const node_fetch_1 = __importDefault(require("node-fetch"));
/* -----------------------------------------------------------------------------
 * globals
 * ---------------------------------------------------------------------------*/
// Polyfill for fetch that is used by nextImageOptimizer
// https://github.com/vercel/next.js/blob/canary/packages/next/server/image-optimizer.ts#L223
// @ts-ignore
global.fetch = node_fetch_1.default;
/* -----------------------------------------------------------------------------
 * Pixel
 * ---------------------------------------------------------------------------*/
const defaultImageConfig = config_shared_1.defaultConfig.images;
class Pixel {
    constructor(options) {
        var _a;
        // Create next config mock
        this.nextConfig = {
            images: (_a = {
                ...defaultImageConfig,
                ...options.imageConfig,
            }) !== null && _a !== void 0 ? _a : defaultImageConfig,
        };
        this.requestHandler = options.requestHandler;
    }
    async imageOptimizer(req, res, parsedUrl, paramsResult) {
        const internalParamsResult = paramsResult !== null && paramsResult !== void 0 ? paramsResult : image_optimizer_1.ImageOptimizerCache.validateParams(req, parsedUrl.query, this.nextConfig, false);
        if ('errorMessage' in internalParamsResult) {
            return { error: internalParamsResult.errorMessage, statusCode: 400 };
        }
        try {
            const imageOptimizerResult = await (0, image_optimizer_1.imageOptimizer)(req, res, internalParamsResult, this.nextConfig, this.requestHandler);
            return {
                ...imageOptimizerResult,
                paramsResult: internalParamsResult,
            };
        }
        catch (error) {
            if (error instanceof image_optimizer_1.ImageError) {
                return {
                    error: error.message,
                    statusCode: error.statusCode,
                };
            }
            // Unhandled error
            throw error;
        }
    }
}
exports.Pixel = Pixel;
